Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2484)

Unified Diff: chrome/browser/ui/autofill/autofill_popup_delegate.h

Issue 11636040: AutofillPopupController clarifications + simplifications. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: new workstation Created 8 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/autofill/autofill_popup_delegate.h
diff --git a/chrome/browser/ui/autofill/autofill_popup_delegate.h b/chrome/browser/ui/autofill/autofill_popup_delegate.h
index 38f99e3a8efea95038291dac91c3a0288dffd1be..c419f3f86ec76375ba136940f32ed3fae72cc33a 100644
--- a/chrome/browser/ui/autofill/autofill_popup_delegate.h
+++ b/chrome/browser/ui/autofill/autofill_popup_delegate.h
@@ -11,21 +11,15 @@
// of events by the controller.
class AutofillPopupDelegate {
public:
// Called when the autofill suggestion indicated by |unique_id| has been
// temporarily selected (e.g., hovered).
- virtual void SelectAutofillSuggestion(int unique_id) = 0;
+ virtual void DidSelectSuggestion(int identifier) = 0;
// Inform the delegate that a row in the popup has been chosen.
- // TODO(estade): does this really need to return a value?
- virtual bool DidAcceptAutofillSuggestion(const string16& value,
- int unique_id,
- unsigned index) = 0;
+ virtual void DidAcceptSuggestion(const string16& value, int identifier) = 0;
- // Remove the given Autocomplete entry from the DB.
- virtual void RemoveAutocompleteEntry(const string16& value) = 0;
-
- // Remove the given Autofill profile or credit credit.
- virtual void RemoveAutofillProfileOrCreditCard(int unique_id) = 0;
+ // Delete the described suggestion.
+ virtual void RemoveSuggestion(const string16& value, int identifier) = 0;
// Informs the delegate that the Autofill previewed form should be cleared.
virtual void ClearPreviewedForm() = 0;
@@ -11,21 +11,15 @@
class AutofillPopupDelegate {
public:
- // Called when the autofill suggestion indicated by |unique_id| has been
+ // Called when the autofill suggestion indicated by |identifier| has been
// temporarily selected (e.g., hovered).

Powered by Google App Engine
This is Rietveld 408576698